@@ -36,12 +36,14 @@ metadata_my_passed_test, _ = m.SuiteMetadata.objects.get_or_create(kind='test',
 metadata_my_failed_test, _ = m.SuiteMetadata.objects.get_or_create(kind='test', suite=suite.slug, name='my_failed_test')
 metadata_my_xfailed_test, _ = m.SuiteMetadata.objects.get_or_create(kind='test', suite=suite.slug, name='my_xfailed_test')
 metadata_my_skipped_test, _ = m.SuiteMetadata.objects.get_or_create(kind='test', suite=suite.slug, name='my_skipped_test')
+metadata_my_metric, _ = m.SuiteMetadata.objects.get_or_create(kind='metric', suite=suite.slug, name='my_metric')
 
 testrun = build.test_runs.create(environment=environment)
 passed_test = testrun.tests.create(suite=suite, result=True, metadata=metadata_my_passed_test, build=testrun.build, environment=testrun.environment)
 failed_test = testrun.tests.create(suite=suite, result=False, metadata=metadata_my_failed_test, build=testrun.build, environment=testrun.environment)
 xfailed_test = testrun.tests.create(suite=suite, result=True, metadata=metadata_my_xfailed_test, has_known_issues=True, build=testrun.build, environment=testrun.environment)
 skipped_test = testrun.tests.create(suite=suite, result=None, metadata=metadata_my_skipped_test, build=testrun.build, environment=testrun.environment)
+my_metric = testrun.metrics.create(suite=suite, result=1, metadata=metadata_my_metric, build=testrun.build, environment=testrun.environment)
 
 RecordTestRunStatus()(testrun)
 
@@ -50,5 +52,5 @@ testjob = testrun.test_jobs.create(backend=backend, target=project, target_build
 
 emailtemplate = m.EmailTemplate.objects.create(name='my_emailtemplate')
 suitemetadata = m.SuiteMetadata.objects.create(name='my_suitemetadata')
-metricthreshold = m.MetricThreshold.objects.create(environment=environment, value=42)
+metricthreshold = project.thresholds.create(environment=environment, value=42, name='my-threshold')
 report = build.delayed_reports.create()
