@@ -9,6 +9,7 @@ from squad_client.shortcuts import (
     retrieve_latest_builds,
     retrieve_build_results,
     submit_results,
+    submit_job,
     create_or_update_project,
 )
 
@@ -74,6 +75,34 @@ class SubmitResultsShortcutTest(TestCase):
         self.assertFalse(success)
 
 
+class SubmitJobShortcutTest(TestCase):
+    def setUp(self):
+        self.squad = Squad()
+        SquadApi.configure(
+            url="http://localhost:%s" % settings.DEFAULT_SQUAD_PORT,
+            token="193cd8bb41ab9217714515954e8724f651ef8601",
+        )
+
+    def test_basic(self):
+        success = submit_job(
+            group_project_slug="my_group/my_project",
+            build_version="my_build",
+            env_slug="my_submitted_env",
+            backend_name="my_backend",
+            definition="tests/data/dummy-definition.yaml",
+        )
+
+        self.assertTrue(success)
+        results = self.squad.testjobs()
+        self.assertTrue(len(results) > 0)
+
+        for testjob in results.values():
+            if testjob.environment == "my_submitted_env":
+                return
+
+        self.assertTrue(False)
+
+
 class CreateOrUpdateShortcutTest(TestCase):
     def setUp(self):
         self.squad = Squad()
